﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics;
using Infragistics.Controls.Charts;
using System.Windows.Markup;

namespace StackedColumnsMarkersWithGroupBy
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        ObservableCollection<Data> data = new ObservableCollection<Data>();
        List<string> stats = new List<string>
            {
                "1 PPD",
                "2 PPD",
                "3 PPD", 
            };

        public MainWindow()
        {
            InitializeComponent();

            Random r = new Random();
            for (int i = 0; i < 4; i++)
            {
                foreach (string stat in stats)
                {
                    data.Add(new Data
                    {
                        stat = stat,
                        date = DateTime.Now.AddDays(i).Date,
                        price = r.NextDouble()
                    });
                }
            }

            GroupBy source = new GroupBy();
            source.GroupMemberPath = "LS_SourceStartDate";
            source.ValueMemberPath = "UPBPercent";
            source.KeyMemberPath = "SG_Status";
            source.ItemsSource = data;

            xAxis.ItemsSource = source;


            StackedColumnSeries series = new StackedColumnSeries
            {
                HorizontalAlignment = HorizontalAlignment.Stretch,
                VerticalAlignment = VerticalAlignment.Stretch,
                HorizontalContentAlignment = HorizontalAlignment.Stretch,
                VerticalContentAlignment = VerticalAlignment.Stretch,
                XAxis = xAxis,
                YAxis = yAxis,
                Title = "Series",
                AutoGenerateSeries = true
            };
            series.ItemsSource = source;

            series.SeriesCreated += (ss, ee) =>
                {
                    StackedFragmentSeries ser = (StackedFragmentSeries)ss;
                    var xaml = @"
                     <DataTemplate x:Key='FlowRateMarkerTemplate'
                         xmlns='http://schemas.microsoft.com/winfx/2006/xaml/presentation' 
                         xmlns:x='http://schemas.microsoft.com/winfx/2006/xaml'>
                           <TextBlock Margin='2' Text='{Binding Item." + ser.ValueMemberPath + @"}' 
                                                             Foreground='White' FontSize='15' FontWeight='Bold'
                                                             HorizontalAlignment='Center' />
                     </DataTemplate>";

                    var markerTemplate = XamlReader.Parse(xaml) as DataTemplate;
                    ee.Title =
                    ee.MarkerTemplate = markerTemplate;
                };

            xamDataChart1.Series.Add(series);
        }
    }

    public class Data
    {
        public DateTime date;
        public DateTime LS_SourceStartDate
        {
            get
            {
                return date;
            }
            set
            {
                date = value;
            }
        }

        public string stat;
        public string SG_Status
        {
            get
            {
                return stat;
            }
            set
            {
                stat = value;
            }
        }

        public double price;
        public double UPBPercent
        {
            get
            {
                return price;
            }
            set
            {
                price = value;
            }
        }
    }
}
